@@ -1,4 +1,3 @@
-context("Testing dummy MCMCdef")
 
 test_that("compareMCMCs works", {
   res <- compareMCMCs::compareMCMCs(needRmodel = FALSE,
@@ -15,3 +14,10 @@ test_that("compareMCMCs works", {
               "dummy"))
 }
 )
+
+##   res <- compareMCMCs::compareMCMCs(needRmodel = FALSE,
+##                                     MCMCs = c('dummy'),
+##                                     monitors = paste0("x[", 1:20, "]"),
+##                                     MCMCcontrol = list(niter = 2000))
+## make_MCMC_comparison_pages(res, modelName = "dummy")
+## browseURL(file.path(tempdir(), "dummy.html"))
